%define lib_major       2
%define lib_name        %mklibname ffado %{lib_major}
%define lib_name_devel  %mklibname ffado -d

Name:           libffado
Summary:        Firewire audio drivers for JACK
Version:        2.4.9
Release:        %mkrel 2
License:        GPLv2+ and GPLv3
Group:          Sound/Utilities
URL:            https://www.ffado.org/
Source0:        https://www.ffado.org/files/%{name}-%{version}.tgz
Patch0:         libffado-linking.patch

BuildRequires:  scons
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libraw1394)
BuildRequires:  pkgconfig(libiec61883)
BuildRequires:  pkgconfig(libxml++-2.6)
BuildRequires:  pkgconfig(jack)
BuildRequires:  python3-qt5-devel
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libconfig)
BuildRequires:  pkgconfig(dbus-c++-1)
BuildRequires:  python3dist(dbus-python)

%description
The FFADO library provides a generic, open-source solution for the
support of FireWire based audio devices for the Linux platform. It is the
successor of the FreeBoB project. Currently this library is used by the
firewire backends of the jack audio connection kit sound server
(jackit package). This backend provides audio and midi support,
and is available in both jack1 and jack2.

#-----------------------------------

%package -n %{lib_name}
Summary:        Firewire audio drivers for JACK
Group:          Sound/Utilities

%description -n %{lib_name}
The FFADO library provides a generic, open-source solution for the
support of FireWire based audio devices for the Linux platform. It is the
successor of the FreeBoB project. Currently this library is used by the
firewire backends of the jack audio connection kit sound server
(jackit package). This backend provides audio and midi support,
and is available in both jack1 and jack2.

%files -n %{lib_name}
%doc AUTHORS ChangeLog LICENSE.* README
%{_libdir}/libffado.so.%{lib_major}{,.*}

#-----------------------------------

%package -n ffado
Summary:        Firewire audio driver applications and utilities
Group:          Sound/Utilities
Requires:       %{lib_name} = %{version}-%{release}
Requires:       python3dist(dbus-python)
Requires:       qttools5-qtdbus
Requires:       python3-qt5-core
Requires:       python3-qt5-gui
Requires:       python3-qt5-network
Requires:       python3-qt5-widgets

%description -n ffado
Configuration utilities for the FFADO firewire drivers.

%files -n ffado
%{_bindir}/*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/python
%{_datadir}/%{name}/configuration
%{_datadir}/%{name}/icons
%{_datadir}/%{name}/*.xml
%{_datadir}/applications/org.ffado.FfadoMixer.desktop
%{_iconsdir}/hicolor/*/apps/hi64-apps-ffado.png
%{_datadir}/dbus-1/services/org.ffado.Control.service
%{_metainfodir}/org.ffado.FfadoMixer.metainfo.xml
%{_udevrulesdir}/60-ffado.rules
%{python3_sitelib}/ffado/
%{_mandir}/man1/*

#-----------------------------------

%package -n %{lib_name_devel}
Summary:        Firewire audio driver library development headers
Group:          Sound/Utilities
Requires:       %{lib_name} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{lib_name_devel}
Development files needed to build applications against libffado.

%files -n %{lib_name_devel}
%{_libdir}/%{name}.so
%{_libdir}/libffado/static_info.txt
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_libdir}/pkgconfig/%{name}.pc

#-----------------------------------

%prep
%autosetup -p1

# Fix Python shebangs
%py3_shebang_fix \
    admin/*.py doc/SConscript tests/python/*.py tests/*.py \
    support/mixer-qt4/ffado-mixer* support/mixer-qt4/SConscript \
    support/tools/*.py support/tools/SConscript

%build
%set_build_flags
%scons \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    PYTHON_INTERPRETER=%{__python3} \
    PYPKGDIR=%{python3_sitelib} \
    UDEVDIR=%{_udevrulesdir} \
    CUSTOM_ENV=True

%install
%set_build_flags
%scons_install \
    PREFIX=%{_prefix} \
    LIBDIR=%{_libdir} \
    MANDIR=%{_mandir}

install -D -m 0644 support/tools/ffado-sandbox-install.py %{buildroot}%{_datadir}/libffado/python


%changelog
* Fri Mar 07 2025 daviddavid <daviddavid> 2.4.9-2.mga10
+ Revision: 2161377
- rebuild for python 3.13

* Fri Sep 20 2024 daviddavid <daviddavid> 2.4.9-1.mga10
+ Revision: 2099428
- new version: 2.4.9
+ danf <danf>
- Update links to https:

* Thu Feb 15 2024 daviddavid <daviddavid> 2.4.8-1.mga10
+ Revision: 2041492
- new version: 2.4.8

* Sun Feb 11 2024 daviddavid <daviddavid> 2.4.7-2.mga10
+ Revision: 2040290
- add fedora patches to fix build with py3.12
- rebuild for py3.12

* Mon Dec 19 2022 daviddavid <daviddavid> 2.4.7-1.mga9
+ Revision: 1925325
- new version: 2.4.7

* Wed Nov 23 2022 daviddavid <daviddavid> 2.4.6-1.mga9
+ Revision: 1910617
- new version: 2.4.6
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 2.4.5-1.mga9
+ Revision: 1787163
- version 2.4.5
- rebuild for python-3.10

* Thu Mar 25 2021 daviddavid <daviddavid> 2.4.4-2.mga9
+ Revision: 1710180
- rebuild for python 3.9

* Wed Sep 09 2020 zezinho <zezinho> 2.4.4-1.mga8
+ Revision: 1623873
- new version 2.4.4

* Sun May 31 2020 zezinho <zezinho> 2.4.3-1.mga8
+ Revision: 1589211
- new version 2.4.3

* Mon Apr 20 2020 wally <wally> 2.4.2-3.mga8
+ Revision: 1570143
- build using our compiler flags
- add patch to fix underlinking

* Sun Feb 16 2020 umeabot <umeabot> 2.4.2-2.mga8
+ Revision: 1534242
- Mageia 8 Mass Rebuild

* Mon Sep 30 2019 zezinho <zezinho> 2.4.2-1.mga8
+ Revision: 1448219
- new version 2.4.2

* Sat Sep 21 2019 daviddavid <daviddavid> 2.4.1-5.mga8
+ Revision: 1444419
- rebuild for python3.8
- switch to python3-scons

* Tue May 07 2019 daviddavid <daviddavid> 2.4.1-4.mga7
+ Revision: 1396625
- switch to PyQt5 and Python3

* Fri Apr 05 2019 daviddavid <daviddavid> 2.4.1-3.mga7
+ Revision: 1386000
- switch to Python2 scons support

* Sun Sep 23 2018 umeabot <umeabot> 2.4.1-2.mga7
+ Revision: 1298840
- Mageia 7 Mass Rebuild

* Fri Apr 06 2018 kekepower <kekepower> 2.4.1-1.mga7
+ Revision: 1215661
- Update to version 2.4.1

* Sat Feb 03 2018 zezinho <zezinho> 2.4.0-1.mga7
+ Revision: 1198730
- new BR jack
- fix deprecated flags
- new version 2.4.0

* Wed Oct 11 2017 daviddavid <daviddavid> 2.3.0-2.mga7
+ Revision: 1170858
- patch2: fix build with gcc6
- patch1: fix build with gcc7
- patch0: fix build with scons 3.0

* Thu Aug 11 2016 luigiwalser <luigiwalser> 2.3.0-1.mga6
+ Revision: 1045623
- 2.3.0
- remove upstreamed patch

* Mon Feb 15 2016 umeabot <umeabot> 2.2.1-5.mga6
+ Revision: 961052
- Mageia 6 Mass Rebuild

* Sun Aug 30 2015 cjw <cjw> 2.2.1-4.mga6
+ Revision: 871124
- patch: remove declarations of errno in 2 test sources
- set compile flags and add -std=gnu++11 to fix build

* Wed Oct 15 2014 umeabot <umeabot> 2.2.1-3.mga5
+ Revision: 745168
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.2.1-2.mga5
+ Revision: 681455
- Mageia 5 Mass Rebuild

* Thu Jul 10 2014 luigiwalser <luigiwalser> 2.2.1-1.mga5
+ Revision: 651129
- 2.2.1

* Sat May 31 2014 pterjan <pterjan> 2.1.0-5.mga5
+ Revision: 628293
- Rebuild for new Python

* Fri Oct 18 2013 umeabot <umeabot> 2.1.0-4.mga4
+ Revision: 506967
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.1.0-3.mga3
+ Revision: 357098
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 27 2012 zezinho <zezinho> 2.1.0-2.mga3
+ Revision: 322464
- fix rpm group

* Tue Sep 25 2012 mitya <mitya> 2.1.0-1.mga3
+ Revision: 297351
- Fix file list
+ zezinho <zezinho>
- fix file list
- new version
- remove now useless bootstrap

* Tue May 01 2012 mitya <mitya> 2.0.1-6.mga2
+ Revision: 234460
- Fix jackd segafult in FFADO's DebugModule (FFADO Bug #329)

* Tue Feb 07 2012 zezinho <zezinho> 2.0.1-5.mga2
+ Revision: 206146
- rebuild against new glib
- cleanup spec
+ tv <tv>
- new release

* Mon Apr 25 2011 wally <wally> 2.0.1-4.mga1
+ Revision: 90328
- fix desktop file (mga#954)
+ dmorgan <dmorgan>
- Enable bootstrap
- Remove mdv macros
  Bootstrap to allow to build without python-qt4-devel
- imported package libffado


* Sun Oct 17 2010 Frank Kober <emuse@mandriva.org> 2.0.1-3mdv2011.0
+ Revision: 586202
- kill qt3 dependency for devel package as well

* Sun Oct 10 2010 Frank Kober <emuse@mandriva.org> 2.0.1-2mdv2011.0
+ Revision: 584640
- remove obsolete dbus-qt3 BR

* Thu Jul 15 2010 Frank Kober <emuse@mandriva.org> 2.0.1-1mdv2011.0
+ Revision: 553651
- new version 2.0.1 now working with new fw kernel stack

* Sat Mar 20 2010 Frank Kober <emuse@mandriva.org> 2.0.0-3mdv2010.1
+ Revision: 525563
- add python-qt4 to Requires, bump release

* Sun Feb 28 2010 Frank Kober <emuse@mandriva.org> 2.0.0-2mdv2010.1
+ Revision: 512749
- rebuild with dependencies in main/release

* Sat Feb 27 2010 Frank Kober <emuse@mandriva.org> 2.0.0-1mdv2010.1
+ Revision: 512339
-update group tag
-add python-dbus BR
-fix icon path
- import ffado version 2.0.0
- import libffado


